@@ -1,7 +1,7 @@
 #!/bin/bash
 
 check() {
-	[ -n "$hostonly" -a -c /sys/class/infiniband_verbs/uverbs0 ] && return 0
+	[ -n "$hostonly" -a -d /sys/class/infiniband_verbs/uverbs0 ] && return 0
 	[ -n "$hostonly" ] && return 255
 	return 0
 }
@@ -25,6 +25,13 @@ install() {
 	inst_multiple -o \
                   $systemdsystemunitdir/rdma-hw.target \
                   $systemdsystemunitdir/rdma-load-modules@.service
+
+	for i in \
+		rdma-load-modules@rdma.service \
+		rdma-load-modules@roce.service \
+		rdma-load-modules@infiniband.service; do
+		$SYSTEMCTL -q --root "$initdir" add-wants initrd.target "$i"
+	done
 }
 
 installkernel() {
